@@ -2,7 +2,6 @@ mod tag;
 
 use std::{
     collections::HashMap,
-    convert::TryFrom,
     error, fmt,
     io::{self, Write},
 };
@@ -113,8 +112,8 @@ where
 
         encode_itf8(
             encoding,
-            &mut self.core_data_writer,
-            &mut self.external_data_writers,
+            self.core_data_writer,
+            self.external_data_writers,
             bam_bit_flags,
         )
     }
@@ -129,8 +128,8 @@ where
 
         encode_itf8(
             encoding,
-            &mut self.core_data_writer,
-            &mut self.external_data_writers,
+            self.core_data_writer,
+            self.external_data_writers,
             cram_bit_flags,
         )
     }
@@ -193,8 +192,8 @@ where
             .and_then(|encoding| {
                 encode_itf8(
                     encoding,
-                    &mut self.core_data_writer,
-                    &mut self.external_data_writers,
+                    self.core_data_writer,
+                    self.external_data_writers,
                     reference_id,
                 )
             })
@@ -211,8 +210,8 @@ where
 
         encode_itf8(
             encoding,
-            &mut self.core_data_writer,
-            &mut self.external_data_writers,
+            self.core_data_writer,
+            self.external_data_writers,
             len,
         )
     }
@@ -225,8 +224,8 @@ where
 
         encode_itf8(
             encoding,
-            &mut self.core_data_writer,
-            &mut self.external_data_writers,
+            self.core_data_writer,
+            self.external_data_writers,
             alignment_start,
         )
     }
@@ -239,8 +238,8 @@ where
 
         encode_itf8(
             encoding,
-            &mut self.core_data_writer,
-            &mut self.external_data_writers,
+            self.core_data_writer,
+            self.external_data_writers,
             read_group,
         )
     }
@@ -258,8 +257,8 @@ where
             .and_then(|encoding| {
                 encode_byte_array(
                     encoding,
-                    &mut self.core_data_writer,
-                    &mut self.external_data_writers,
+                    self.core_data_writer,
+                    self.external_data_writers,
                     read_name,
                 )
             })
@@ -307,8 +306,8 @@ where
 
                 encode_itf8(
                     encoding,
-                    &mut self.core_data_writer,
-                    &mut self.external_data_writers,
+                    self.core_data_writer,
+                    self.external_data_writers,
                     next_mate_bit_flags,
                 )
             })
@@ -332,8 +331,8 @@ where
             .and_then(|encoding| {
                 encode_itf8(
                     encoding,
-                    &mut self.core_data_writer,
-                    &mut self.external_data_writers,
+                    self.core_data_writer,
+                    self.external_data_writers,
                     next_fragment_reference_sequence_id,
                 )
             })
@@ -358,8 +357,8 @@ where
 
         encode_itf8(
             encoding,
-            &mut self.core_data_writer,
-            &mut self.external_data_writers,
+            self.core_data_writer,
+            self.external_data_writers,
             position,
         )
     }
@@ -377,8 +376,8 @@ where
             .and_then(|encoding| {
                 encode_itf8(
                     encoding,
-                    &mut self.core_data_writer,
-                    &mut self.external_data_writers,
+                    self.core_data_writer,
+                    self.external_data_writers,
                     template_size,
                 )
             })
@@ -400,8 +399,8 @@ where
             .and_then(|encoding| {
                 encode_itf8(
                     encoding,
-                    &mut self.core_data_writer,
-                    &mut self.external_data_writers,
+                    self.core_data_writer,
+                    self.external_data_writers,
                     distance_to_next_fragment,
                 )
             })
@@ -442,8 +441,8 @@ where
 
             encode_byte_array(
                 encoding,
-                &mut self.core_data_writer,
-                &mut self.external_data_writers,
+                self.core_data_writer,
+                self.external_data_writers,
                 &buf,
             )?;
         }
@@ -459,8 +458,8 @@ where
 
         encode_itf8(
             encoding,
-            &mut self.core_data_writer,
-            &mut self.external_data_writers,
+            self.core_data_writer,
+            self.external_data_writers,
             tag_line,
         )
     }
@@ -505,8 +504,8 @@ where
 
                 encode_itf8(
                     encoding,
-                    &mut self.core_data_writer,
-                    &mut self.external_data_writers,
+                    self.core_data_writer,
+                    self.external_data_writers,
                     number_of_read_features,
                 )
             })
@@ -574,8 +573,8 @@ where
 
                 encode_itf8(
                     encoding,
-                    &mut self.core_data_writer,
-                    &mut self.external_data_writers,
+                    self.core_data_writer,
+                    self.external_data_writers,
                     feature_code,
                 )
             })
@@ -594,8 +593,8 @@ where
             .and_then(|encoding| {
                 encode_itf8(
                     encoding,
-                    &mut self.core_data_writer,
-                    &mut self.external_data_writers,
+                    self.core_data_writer,
+                    self.external_data_writers,
                     position,
                 )
             })
@@ -614,8 +613,8 @@ where
             .and_then(|encoding| {
                 encode_byte_array(
                     encoding,
-                    &mut self.core_data_writer,
-                    &mut self.external_data_writers,
+                    self.core_data_writer,
+                    self.external_data_writers,
                     bases,
                 )
             })
@@ -636,8 +635,8 @@ where
             .and_then(|encoding| {
                 encode_byte_array(
                     encoding,
-                    &mut self.core_data_writer,
-                    &mut self.external_data_writers,
+                    self.core_data_writer,
+                    self.external_data_writers,
                     quality_scores,
                 )
             })
@@ -656,8 +655,8 @@ where
             .and_then(|encoding| {
                 encode_byte(
                     encoding,
-                    &mut self.core_data_writer,
-                    &mut self.external_data_writers,
+                    self.core_data_writer,
+                    self.external_data_writers,
                     base,
                 )
             })
@@ -676,8 +675,8 @@ where
             .and_then(|encoding| {
                 encode_byte(
                     encoding,
-                    &mut self.core_data_writer,
-                    &mut self.external_data_writers,
+                    self.core_data_writer,
+                    self.external_data_writers,
                     quality_score,
                 )
             })
@@ -696,8 +695,8 @@ where
             .and_then(|encoding| {
                 encode_byte(
                     encoding,
-                    &mut self.core_data_writer,
-                    &mut self.external_data_writers,
+                    self.core_data_writer,
+                    self.external_data_writers,
                     code,
                 )
             })
@@ -716,8 +715,8 @@ where
             .and_then(|encoding| {
                 encode_byte_array(
                     encoding,
-                    &mut self.core_data_writer,
-                    &mut self.external_data_writers,
+                    self.core_data_writer,
+                    self.external_data_writers,
                     bases,
                 )
             })
@@ -736,8 +735,8 @@ where
             .and_then(|encoding| {
                 encode_itf8(
                     encoding,
-                    &mut self.core_data_writer,
-                    &mut self.external_data_writers,
+                    self.core_data_writer,
+                    self.external_data_writers,
                     len,
                 )
             })
@@ -756,8 +755,8 @@ where
             .and_then(|encoding| {
                 encode_itf8(
                     encoding,
-                    &mut self.core_data_writer,
-                    &mut self.external_data_writers,
+                    self.core_data_writer,
+                    self.external_data_writers,
                     len,
                 )
             })
@@ -776,8 +775,8 @@ where
             .and_then(|encoding| {
                 encode_byte_array(
                     encoding,
-                    &mut self.core_data_writer,
-                    &mut self.external_data_writers,
+                    self.core_data_writer,
+                    self.external_data_writers,
                     bases,
                 )
             })
@@ -796,8 +795,8 @@ where
             .and_then(|encoding| {
                 encode_itf8(
                     encoding,
-                    &mut self.core_data_writer,
-                    &mut self.external_data_writers,
+                    self.core_data_writer,
+                    self.external_data_writers,
                     len,
                 )
             })
@@ -816,8 +815,8 @@ where
             .and_then(|encoding| {
                 encode_itf8(
                     encoding,
-                    &mut self.core_data_writer,
-                    &mut self.external_data_writers,
+                    self.core_data_writer,
+                    self.external_data_writers,
                     len,
                 )
             })
@@ -836,8 +835,8 @@ where
             .and_then(|encoding| {
                 encode_itf8(
                     encoding,
-                    &mut self.core_data_writer,
-                    &mut self.external_data_writers,
+                    self.core_data_writer,
+                    self.external_data_writers,
                     mapping_quality,
                 )
             })
